==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/de_DE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "erforderlich",
    "Optional" : "optional",
    "Does not attend" : "Nimmt nicht teil",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sie sind in einer unbekannten Zeitzone ({tz}), auf UTC wird geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neuer Termin",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "wenn geteilt, zeige nur 'beschäftigt'",
    "When shared hide this event" : "wenn geteilt, zeige den Termin nicht an",
    "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
    "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "At time of event" : "Zum Zeitpunkt des Termins",
    "5 minutes before" : "5 Minuten vor",
    "10 minutes before" : "10 Minuten vor",
    "15 minutes before" : "15 Minuten vor",
    "30 minutes before" : "30 Minuten vor",
    "1 hour before" : "1 Stunde vor",
    "2 hours before" : "2 Stunden vor",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop up",
    "sec" : "sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tage",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of uknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert, {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Termins",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Termins",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Termins",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Termins",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Title of the Event" : "Bezeichnung des Termins",
    "starts" : "Beginnt",
    "ends" : "endet",
    "All day Event" : "Ganztägiger Termin",
    "Location" : "Ort",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr...",
    "Create" : "Erstellen",
    "Update" : "Update durchführen",
    "Close" : "Schließen",
    "Description" : "Beschreibung",
    "Export" : "Exportieren",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktieren Sie ihren Administrator und bitten Sie ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Share Calendar" : "Kalender freigeben",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "CalDAV" : "CalDAV",
    "group" : "Gruppe",
    "New Calendar" : "Neuer Kalender",
    "Subscriptions" : "Abonnements",
    "New Subscription" : "neues Abonnement",
    "Url" : "Url",
    "Edit event" : "Termin bearbeiten",
    "Delete Event" : "Termin löschen",
    "Save Event" : "Termin speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte fügen Sie ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "wiederhole jeden ...",
    "end repeat ..." : "Wiederholung beenden ...",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Importieren abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält ein Objekt, dass inkompatibel ist mit dem ausgewählten Kalender",
    "New calendar" : "Neuer Kalender",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Import calendar" : "Kalendar importieren",
    "No Calendars selected for import" : "Es wurde kein Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/de_DE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "erforderlich",
    "Optional" : "optional",
    "Does not attend" : "Nimmt nicht teil",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sie sind in einer unbekannten Zeitzone ({tz}), auf UTC wird geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neuer Termin",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "wenn geteilt, zeige nur 'beschäftigt'",
    "When shared hide this event" : "wenn geteilt, zeige den Termin nicht an",
    "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
    "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "At time of event" : "Zum Zeitpunkt des Termins",
    "5 minutes before" : "5 Minuten vor",
    "10 minutes before" : "10 Minuten vor",
    "15 minutes before" : "15 Minuten vor",
    "30 minutes before" : "30 Minuten vor",
    "1 hour before" : "1 Stunde vor",
    "2 hours before" : "2 Stunden vor",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop up",
    "sec" : "sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tage",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert, {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Termins",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Termins",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Termins",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Termins",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Title of the Event" : "Bezeichnung des Termins",
    "starts" : "Beginnt",
    "ends" : "endet",
    "All day Event" : "Ganztägiger Termin",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr...",
    "Create" : "Erstellen",
    "Update" : "Update durchführen",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Export" : "Exportieren",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktieren Sie ihren Administrator und bitten Sie ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Share Calendar" : "Kalender freigeben",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "group" : "Gruppe",
    "New Calendar" : "Neuer Kalender",
    "Subscriptions" : "Abonnements",
    "New Subscription" : "neues Abonnement",
    "Url" : "Url",
    "Edit event" : "Termin bearbeiten",
    "Delete Event" : "Termin löschen",
    "Save Event" : "Termin speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte fügen Sie ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "wiederhole jeden ...",
    "end repeat ..." : "Wiederholung beenden ...",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Importieren abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält ein Objekt, dass inkompatibel ist mit dem ausgewählten Kalender",
    "New calendar" : "Neuer Kalender",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Import calendar" : "Kalendar importieren",
    "No Calendars selected for import" : "Es wurde kein Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");
